@@ -138,6 +138,9 @@
 #define ERR_RELOAD_SERVER	"%s: Cannot start reload server."
 #define ERR_ZIP_CONVERT		"%s: Cannot zip convert.(%s)"
 #define ERR_CHARCODE_CONVERT	"%s: Cannot convert character code."
+#define ERR_CONVERT_VALIDATION	"Failed to validate charset conversion: (Attachfilename[base64]: original: %s, converted: %s, validation: %s, FromChar: %s, ToChar: %s)."
+#define DEBUG_CONVERT_VALIDATION "Validation for charset conversion: (Attachfilename[base64]: original: %s, converted: %s, validation: %s, FromChar: %s, ToChar: %s)."
+#define MAX_STRCODE_LEN	        16
 
 #define ERR_NULL_FILE_NAME      "%s: samma atlist is NULL."
 #define ERR_STR_CODE		"Invalid str code."
