@@ -290,15 +290,37 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
 
         /* user policy check */
         if (user_policy == ENC) {
-            ret = search_rcptaddr_ldap(&res, cfg, rcptaddr, passlist, rdmpasslist);
+            ret = search_rcptaddr_ldap(&res, cfg, rcptaddr,
+                                       passlist, rdmpasslist);
             if (ret == ERROR) {
                 free_search_rcptaddr(&res);
                 return ERROR;
             } else if (ret == NOT_ENC) {
                 continue;
             }
-            enc_status = ENC;
+            if (ret != UNDEF_ENC) {
+                enc_status = ENC;
+                // case ret == ENC: already added to encryption rcpt list
+                //       so continue anyway
+                continue;
+            }
         }
+
+        /* default user policy check */
+        if ((cfg->cf_userpolicy[0] == 'Y' || cfg->cf_userpolicy[0] == 'y')
+             && (cfg->cf_userdefaultencryption[0] == 'Y'
+                 || cfg->cf_userdefaultencryption[0] == 'y')) {
+            // case UserPolicy is yes, UserDefaultPolicy is yes,
+            //      and recipient is not in userdata of the sender on LDAP
+            enc_status = ENC;
+            ret = check_default_policy(defalt_pass_len, &res, cfg, rcptaddr, 
+                    passlist, rdmpasslist);
+            if (ret != ADD_LIST_SUCCESS) {
+                free_search_rcptaddr(&res);
+                return ERROR;
+            }
+        }
+
     } // rcpt addrlist loop
 
     free_search_rcptaddr(&res);
@@ -418,10 +440,11 @@ search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rc
  * struct rcptinfo ** rdmpasslist	List encrypted by random password
  *
  * return value
- *       ENC            	encryption
- *       NOT_ENC        	no encryption
- *       ERROR  	 	database error
- *	 MALLOC_ERROR		alloc error
+ *       ENC            encryption
+ *       NOT_ENC        no encryption
+ *       UNDEF_ENC      undefined user on ldap: follow the site-policies
+ *       ERROR          database error
+ *	 MALLOC_ERROR       alloc error
  */
 int
 search_rcptaddr_ldap(struct search_res *res, struct config *cfg, 
@@ -453,6 +476,8 @@ search_rcptaddr_ldap(struct search_res *res, struct config *cfg,
         return ERROR;
     } else if (ret == NOT_ENC) {
 	return NOT_ENC;
+    } else if (ret == UNDEF_ENC) {
+        return UNDEF_ENC;
     }
     DEBUGLOG("UserPolicy found.(%s)", data.addr);
 
@@ -1266,6 +1291,7 @@ set_priority_addr (struct person *data, struct berval **valp_addr, struct berval
  * return value
  *       ENC            encryption
  *       NOT_ENC        no encryption
+ *       UNDEF_ENC      undefined user on ldap: follow the site-policies
  *       LDAP_ERROR     ldap error
  *       MALLOC_ERROR   alloc error
  */
@@ -1324,7 +1350,7 @@ ldap_search_policy (LDAP *ld, char *ldapbasedn, char *rcpt, char *userdn, struct
         return LDAP_ERROR;
     } else if (count == 0) {
         ldap_msgfree(res);
-        return NOT_ENC;
+        return UNDEF_ENC;
     }
 
     //find priority address
