@@ -59,7 +59,11 @@
 
 pthread_mutex_t gmime_lock = PTHREAD_MUTEX_INITIALIZER;
 
+#ifndef __CUSTOMIZE2018
 static void zip_child(char **, char *, char *, char *);
+#else   // __CUSTOMIZE2018
+static void zip_child(char **, char *, char *, char *, char *);
+#endif  // __CUSTOMIZE2018
 
 void
 free_name_list(struct name_list *head)
@@ -295,37 +299,37 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
     /* parse mail */
     ret = parse_mail(minfo, cfg, &mz);
     if ((ret == PM_NO_MULTIPART) || (ret == PM_NO_ATTACHFILE)) {
-	mailzip_clean(mz);
-	return ZIP_CONVERT_ACCEPT;
+        mailzip_clean(mz);
+        return ZIP_CONVERT_ACCEPT;
     } else if (ret == PM_FAILED) {
-	mailzip_clean(mz);
-	return ZIP_CONVERT_FAILED;
+        mailzip_clean(mz);
+        return ZIP_CONVERT_FAILED;
     } else if (ret == PM_INVALID_FILENAME) {
-	mailzip_clean(mz);
-	return ZIP_CONVERT_INVALID_FILENAME;
+        mailzip_clean(mz);
+        return ZIP_CONVERT_INVALID_FILENAME;
     }
 
     if (mk_encpath(cfg, &mz) == -1) {
-	mailzip_clean(mz);
-	return ZIP_CONVERT_FAILED;
+        mailzip_clean(mz);
+        return ZIP_CONVERT_FAILED;
     }
 
     if (passlist != NULL) {
 	for (p = passlist; p != NULL; p = p->Next) {
 	    /* encryption */
 	    if (convert_zip(cfg, &mz, p) != 0) {
-		mailzip_clean(mz);
-		return ZIP_CONVERT_FAILED;
+            mailzip_clean(mz);
+            return ZIP_CONVERT_FAILED;
 	    }
 	    /* add attach file */
 	    if (add_attach_file(cfg, &mz, p) != 0) {
-		mailzip_clean(mz);
-		return ZIP_CONVERT_FAILED;
+            mailzip_clean(mz);
+            return ZIP_CONVERT_FAILED;
 	    }
     	    /* send mail */
 	    if (sendmail(&mz, cfg, p, from) != 0) {
-		mailzip_clean(mz);
-		return ZIP_CONVERT_FAILED;
+            mailzip_clean(mz);
+            return ZIP_CONVERT_FAILED;
 	    }
 #ifdef __CUSTOMIZE2018_LOG
             if (ismode_enc) {
@@ -690,6 +694,7 @@ add_attach_file(struct config *cfg, struct mailzip *mz, struct rcptinfo *rcpt)
     int index, i;
     const char *filename;
     char newfilename[FILE_NAME_MAX + 1];
+    char *attach_ctype = NULL;
 
     pthread_mutex_lock(&gmime_lock);
     object = g_mime_message_get_mime_part(mz->message);
@@ -750,10 +755,11 @@ add_attach_file(struct config *cfg, struct mailzip *mz, struct rcptinfo *rcpt)
     part = g_mime_part_new();
 
     /* set part object */
+    attach_ctype = cfg->cf_zipattachmentcontenttype;
 #ifndef GMIME26
-    g_mime_part_set_content_header(part, CONTENTTYPE_HEADER, CONTENTTYPE_ZIP);
+    g_mime_part_set_content_header(part, CONTENTTYPE_HEADER, attach_ctype);
 #else
-    g_mime_object_set_header((GMimeObject *)part, CONTENTTYPE_HEADER, CONTENTTYPE_ZIP);
+    g_mime_object_set_header((GMimeObject *)part, CONTENTTYPE_HEADER, attach_ctype);
 #endif
 
 
@@ -1595,8 +1601,8 @@ replace_extension(char *newfilename, char *filename, char *new_ext)
  *
  * Argument
  *      struct config  *cfg     config structure
- *      char *tmpdir            temporary directory name
- *      char *passwd            encryption password
+ *      struct mailzip *mz      mail structure
+ *      struct rcptinfo *rcpt   recipients
  *
  * Return value
  *      0       Normal end.
@@ -1621,7 +1627,12 @@ convert_zip(struct config *cfg, struct mailzip *mz, struct rcptinfo *rcpt)
      */
     if ((pid = fork()) == 0) {
         /* child process */
+#ifndef __CUSTOMIZE2018
         zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd);
+#else   // __CUSTOMIZE2018
+        zip_child(list, cfg->cf_zipcommandopt, mz->zipdir, rcpt->passwd,
+                    mz->am_priv->mlfi_savefrom);
+#endif  // __CUSTOMIZE2018
     } else if (pid > 0) {
         /* parent process */
         ret = waitpid(pid, &sts, WUNTRACED);
@@ -1652,7 +1663,11 @@ convert_zip(struct config *cfg, struct mailzip *mz, struct rcptinfo *rcpt)
  * child process
  *--------------------------------------------------------*/
 static void
+#ifndef __CUSTOMIZE2018
 zip_child(char **list, char *commandopt, char *dir, char *passwd)
+#else   // __CUSTOMIZE2018
+zip_child(char **list, char *commandopt, char *dir, char *passwd, char *from)
+#endif  // __CUSTOMIZE2018
 {
     char *envstr;
     /*
@@ -1668,11 +1683,17 @@ zip_child(char **list, char *commandopt, char *dir, char *passwd)
     if (setenv(ENV_ZIPOPT, envstr, OVERWRITE) < 0) {
         log(ERR_SET_ENV, "zip_child", ENV_ZIPOPT);
         free(envstr);
-	exit(1);
+        exit(1);
     }
     free(envstr);
+#ifdef __CUSTOMIZE2018
+    if (setenv(ENV_SAMMA_ENVFROM, from, OVERWRITE) < 0) {
+        log(ERR_SET_ENV, "zip_child", ENV_SAMMA_ENVFROM);
+        exit(1);
+    }
+#endif  // __CUSTOMIZE2018
 
-    /* chage encryption directory */
+    /* change encryption directory */
     if (chdir(dir) != 0) {
         log(ERR_DIRECTORY_CHANGE, "zip_child", dir);
         exit(1); 
